# -*- coding: utf-8 -*-
'''
    :file: __init__.py
    :author: -Farmer
    :url: https://blog.farmer233.top
    :date: 2022/01/24 00:48:18
'''
from school_sdk import SchoolClient, UserClient


class School(object):
    school:SchoolClient = None

    def __init__(self, app) -> None:
        if app is not None:
            self.init_app(app)

    def init_app(self, app):
        if not hasattr(app, 'extensions'):
            app.extensions = {}

        school_sdk_config = app.config.get('SCHOOL_SDK_CONFIG', None)

        self.school = SchoolClient(**school_sdk_config)
        app.extensions['school'] = self.school

    def user_login(self, account:str, password:str, **kwargs):
        user = UserClient(self.school, account=account,password=password)
        return user.login()
    
    def dev_user(self, cookies:str = None):
        dev_user = UserClient(self.school)
        return dev_user.get_dev_user(cookies)


# -*- coding: utf-8 -*-
'''
    :file: setup.py
    :author: -Farmer
    :url: https://blog.farmer233.top
    :date: 2022/01/24 14:54:39
'''
from os import path
from codecs import open
from setuptools import setup

basedir = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(basedir, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()


setup(
    name='Flask-School',
    version='0.0.3',
    url='https://github.com/Farmer-chong/flask-school',
    license='MIT',
    author='farmer.chillax',
    author_email='farmer-chong@qq.com',
    description='School SDK extension with flask',
    long_description=long_description,
    long_description_content_type='text/markdown',
    platforms='any',
    packages=['flask_school'],
    zip_safe=False,
    include_package_data=True,
    install_requires=[
        'Flask',
        'school-sdk'
    ],

    keywords='flask extension development',
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.8',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)


# python setup.py bdist_wheel sdist
# twine upload dist/*
